# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/online_store/feature_value.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/online_store/feature_value.proto',
  package='tecton_proto.online_store',
  syntax='proto2',
  serialized_options=b'\n\026com.tecton.onlinestoreP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-tecton_proto/online_store/feature_value.proto\x12\x19tecton_proto.online_store\"\xdf\x02\n\x0c\x46\x65\x61tureValue\x12H\n\x0b\x61rray_value\x18\x01 \x01(\x0b\x32%.tecton_proto.online_store.ArrayValueH\x00R\narrayValue\x12%\n\rfloat64_value\x18\x02 \x01(\x01H\x00R\x0c\x66loat64Value\x12%\n\rfloat32_value\x18\x03 \x01(\x02H\x00R\x0c\x66loat32Value\x12!\n\x0bint64_value\x18\x04 \x01(\x03H\x00R\nint64Value\x12\x1f\n\nbool_value\x18\x05 \x01(\x08H\x00R\tboolValue\x12#\n\x0cstring_value\x18\x06 \x01(\tH\x00R\x0bstringValue\x12\x45\n\nnull_value\x18\x07 \x01(\x0b\x32$.tecton_proto.online_store.NullValueH\x00R\tnullValueB\x07\n\x05value\"b\n\x10\x46\x65\x61tureValueList\x12N\n\x0e\x66\x65\x61ture_values\x18\x01 \x03(\x0b\x32\'.tecton_proto.online_store.FeatureValueR\rfeatureValues\"\xaa\x01\n\rRedisTAFVData\x12\x1f\n\x0b\x61nchor_time\x18\x01 \x01(\x03R\nanchorTime\x12(\n\x10written_by_batch\x18\x02 \x01(\x08R\x0ewrittenByBatch\x12N\n\x0e\x66\x65\x61ture_values\x18\x03 \x03(\x0b\x32\'.tecton_proto.online_store.FeatureValueR\rfeatureValues\"\x0b\n\tNullValue\"\x9f\x02\n\nArrayValue\x12#\n\rstring_values\x18\x01 \x03(\tR\x0cstringValues\x12H\n\x0c\x61rray_values\x18\x02 \x03(\x0b\x32%.tecton_proto.online_store.ArrayValueR\x0b\x61rrayValues\x12%\n\x0cint64_values\x18\x06 \x03(\x03\x42\x02\x10\x01R\x0bint64Values\x12)\n\x0e\x66loat32_values\x18\x07 \x03(\x02\x42\x02\x10\x01R\rfloat32Values\x12)\n\x0e\x66loat64_values\x18\x08 \x03(\x01\x42\x02\x10\x01R\rfloat64Values\x12%\n\x0cnull_indices\x18\t \x03(\x05\x42\x02\x10\x01R\x0bnullIndicesB\x1a\n\x16\x63om.tecton.onlinestoreP\x01'
)




_FEATUREVALUE = _descriptor.Descriptor(
  name='FeatureValue',
  full_name='tecton_proto.online_store.FeatureValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='array_value', full_name='tecton_proto.online_store.FeatureValue.array_value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='arrayValue', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='float64_value', full_name='tecton_proto.online_store.FeatureValue.float64_value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='float64Value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='float32_value', full_name='tecton_proto.online_store.FeatureValue.float32_value', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='float32Value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int64_value', full_name='tecton_proto.online_store.FeatureValue.int64_value', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='int64Value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bool_value', full_name='tecton_proto.online_store.FeatureValue.bool_value', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='boolValue', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='tecton_proto.online_store.FeatureValue.string_value', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='stringValue', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='null_value', full_name='tecton_proto.online_store.FeatureValue.null_value', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nullValue', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='tecton_proto.online_store.FeatureValue.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=77,
  serialized_end=428,
)


_FEATUREVALUELIST = _descriptor.Descriptor(
  name='FeatureValueList',
  full_name='tecton_proto.online_store.FeatureValueList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_values', full_name='tecton_proto.online_store.FeatureValueList.feature_values', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureValues', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=430,
  serialized_end=528,
)


_REDISTAFVDATA = _descriptor.Descriptor(
  name='RedisTAFVData',
  full_name='tecton_proto.online_store.RedisTAFVData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='anchor_time', full_name='tecton_proto.online_store.RedisTAFVData.anchor_time', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='anchorTime', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='written_by_batch', full_name='tecton_proto.online_store.RedisTAFVData.written_by_batch', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='writtenByBatch', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_values', full_name='tecton_proto.online_store.RedisTAFVData.feature_values', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureValues', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=531,
  serialized_end=701,
)


_NULLVALUE = _descriptor.Descriptor(
  name='NullValue',
  full_name='tecton_proto.online_store.NullValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=703,
  serialized_end=714,
)


_ARRAYVALUE = _descriptor.Descriptor(
  name='ArrayValue',
  full_name='tecton_proto.online_store.ArrayValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='string_values', full_name='tecton_proto.online_store.ArrayValue.string_values', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='stringValues', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='array_values', full_name='tecton_proto.online_store.ArrayValue.array_values', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='arrayValues', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int64_values', full_name='tecton_proto.online_store.ArrayValue.int64_values', index=2,
      number=6, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', json_name='int64Values', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='float32_values', full_name='tecton_proto.online_store.ArrayValue.float32_values', index=3,
      number=7, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', json_name='float32Values', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='float64_values', full_name='tecton_proto.online_store.ArrayValue.float64_values', index=4,
      number=8, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', json_name='float64Values', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='null_indices', full_name='tecton_proto.online_store.ArrayValue.null_indices', index=5,
      number=9, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001', json_name='nullIndices', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=717,
  serialized_end=1004,
)

_FEATUREVALUE.fields_by_name['array_value'].message_type = _ARRAYVALUE
_FEATUREVALUE.fields_by_name['null_value'].message_type = _NULLVALUE
_FEATUREVALUE.oneofs_by_name['value'].fields.append(
  _FEATUREVALUE.fields_by_name['array_value'])
_FEATUREVALUE.fields_by_name['array_value'].containing_oneof = _FEATUREVALUE.oneofs_by_name['value']
_FEATUREVALUE.oneofs_by_name['value'].fields.append(
  _FEATUREVALUE.fields_by_name['float64_value'])
_FEATUREVALUE.fields_by_name['float64_value'].containing_oneof = _FEATUREVALUE.oneofs_by_name['value']
_FEATUREVALUE.oneofs_by_name['value'].fields.append(
  _FEATUREVALUE.fields_by_name['float32_value'])
_FEATUREVALUE.fields_by_name['float32_value'].containing_oneof = _FEATUREVALUE.oneofs_by_name['value']
_FEATUREVALUE.oneofs_by_name['value'].fields.append(
  _FEATUREVALUE.fields_by_name['int64_value'])
_FEATUREVALUE.fields_by_name['int64_value'].containing_oneof = _FEATUREVALUE.oneofs_by_name['value']
_FEATUREVALUE.oneofs_by_name['value'].fields.append(
  _FEATUREVALUE.fields_by_name['bool_value'])
_FEATUREVALUE.fields_by_name['bool_value'].containing_oneof = _FEATUREVALUE.oneofs_by_name['value']
_FEATUREVALUE.oneofs_by_name['value'].fields.append(
  _FEATUREVALUE.fields_by_name['string_value'])
_FEATUREVALUE.fields_by_name['string_value'].containing_oneof = _FEATUREVALUE.oneofs_by_name['value']
_FEATUREVALUE.oneofs_by_name['value'].fields.append(
  _FEATUREVALUE.fields_by_name['null_value'])
_FEATUREVALUE.fields_by_name['null_value'].containing_oneof = _FEATUREVALUE.oneofs_by_name['value']
_FEATUREVALUELIST.fields_by_name['feature_values'].message_type = _FEATUREVALUE
_REDISTAFVDATA.fields_by_name['feature_values'].message_type = _FEATUREVALUE
_ARRAYVALUE.fields_by_name['array_values'].message_type = _ARRAYVALUE
DESCRIPTOR.message_types_by_name['FeatureValue'] = _FEATUREVALUE
DESCRIPTOR.message_types_by_name['FeatureValueList'] = _FEATUREVALUELIST
DESCRIPTOR.message_types_by_name['RedisTAFVData'] = _REDISTAFVDATA
DESCRIPTOR.message_types_by_name['NullValue'] = _NULLVALUE
DESCRIPTOR.message_types_by_name['ArrayValue'] = _ARRAYVALUE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeatureValue = _reflection.GeneratedProtocolMessageType('FeatureValue', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREVALUE,
  '__module__' : 'tecton_proto.online_store.feature_value_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.online_store.FeatureValue)
  })
_sym_db.RegisterMessage(FeatureValue)

FeatureValueList = _reflection.GeneratedProtocolMessageType('FeatureValueList', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREVALUELIST,
  '__module__' : 'tecton_proto.online_store.feature_value_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.online_store.FeatureValueList)
  })
_sym_db.RegisterMessage(FeatureValueList)

RedisTAFVData = _reflection.GeneratedProtocolMessageType('RedisTAFVData', (_message.Message,), {
  'DESCRIPTOR' : _REDISTAFVDATA,
  '__module__' : 'tecton_proto.online_store.feature_value_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.online_store.RedisTAFVData)
  })
_sym_db.RegisterMessage(RedisTAFVData)

NullValue = _reflection.GeneratedProtocolMessageType('NullValue', (_message.Message,), {
  'DESCRIPTOR' : _NULLVALUE,
  '__module__' : 'tecton_proto.online_store.feature_value_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.online_store.NullValue)
  })
_sym_db.RegisterMessage(NullValue)

ArrayValue = _reflection.GeneratedProtocolMessageType('ArrayValue', (_message.Message,), {
  'DESCRIPTOR' : _ARRAYVALUE,
  '__module__' : 'tecton_proto.online_store.feature_value_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.online_store.ArrayValue)
  })
_sym_db.RegisterMessage(ArrayValue)


DESCRIPTOR._options = None
_ARRAYVALUE.fields_by_name['int64_values']._options = None
_ARRAYVALUE.fields_by_name['float32_values']._options = None
_ARRAYVALUE.fields_by_name['float64_values']._options = None
_ARRAYVALUE.fields_by_name['null_indices']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/args/feature_view.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tecton_proto.args import basic_info_pb2 as tecton__proto_dot_args_dot_basic__info__pb2
from tecton_proto.args import pipeline_pb2 as tecton__proto_dot_args_dot_pipeline__pb2
from tecton_proto.args import diff_options_pb2 as tecton__proto_dot_args_dot_diff__options__pb2
from tecton_proto.args import virtual_data_source_pb2 as tecton__proto_dot_args_dot_virtual__data__source__pb2
from tecton_proto.common import id_pb2 as tecton__proto_dot_common_dot_id__pb2
from tecton_proto.common import spark_schema_pb2 as tecton__proto_dot_common_dot_spark__schema__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/args/feature_view.proto',
  package='tecton_proto.args',
  syntax='proto2',
  serialized_options=b'\n\017com.tecton.argsP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$tecton_proto/args/feature_view.proto\x12\x11tecton_proto.args\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\"tecton_proto/args/basic_info.proto\x1a tecton_proto/args/pipeline.proto\x1a$tecton_proto/args/diff_options.proto\x1a+tecton_proto/args/virtual_data_source.proto\x1a\x1ctecton_proto/common/id.proto\x1a&tecton_proto/common/spark_schema.proto\"\xfa\x08\n\x0f\x46\x65\x61tureViewArgs\x12?\n\x0f\x66\x65\x61ture_view_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\rfeatureViewId\x12N\n\x11\x66\x65\x61ture_view_type\x18\x02 \x01(\x0e\x32\".tecton_proto.args.FeatureViewTypeR\x0f\x66\x65\x61tureViewType\x12\x37\n\x04info\x18\x03 \x01(\x0b\x32\x1c.tecton_proto.args.BasicInfoB\x05\x92M\x02\x10\x01R\x04info\x12@\n\x08\x65ntities\x18\x04 \x03(\x0b\x32$.tecton_proto.args.EntityKeyOverrideR\x08\x65ntities\x12\x46\n\rtemporal_args\x18\x17 \x01(\x0b\x32\x1f.tecton_proto.args.TemporalArgsH\x00R\x0ctemporalArgs\x12\x62\n\x17temporal_aggregate_args\x18\x18 \x01(\x0b\x32(.tecton_proto.args.TemporalAggregateArgsH\x00R\x15temporalAggregateArgs\x12G\n\x0eon_demand_args\x18\x19 \x01(\x0b\x32\x1f.tecton_proto.args.OnDemandArgsH\x00R\x0conDemandArgs\x12S\n\x12\x66\x65\x61ture_table_args\x18\x1a \x01(\x0b\x32#.tecton_proto.args.FeatureTableArgsH\x00R\x10\x66\x65\x61tureTableArgs\x12+\n\x11\x66ramework_version\x18\x1b \x01(\x05R\x10\x66rameworkVersion\x12\x30\n\x14online_serving_index\x18\x05 \x03(\tR\x12onlineServingIndex\x12,\n\x0eonline_enabled\x18\x0e \x01(\x08\x42\x05\x92M\x02\x08\x01R\ronlineEnabled\x12.\n\x0foffline_enabled\x18\x0f \x01(\x08\x42\x05\x92M\x02\x08\x01R\x0eofflineEnabled\x12\x37\n\x08pipeline\x18\x06 \x01(\x0b\x32\x1b.tecton_proto.args.PipelineR\x08pipeline\x12T\n\x15test_only_view_schema\x18\xe8\x07 \x01(\x0b\x32 .tecton_proto.common.SparkSchemaR\x12testOnlyViewSchema\x12\x64\n\x1dtest_only_materialized_schema\x18\xe9\x07 \x01(\x0b\x32 .tecton_proto.common.SparkSchemaR\x1atestOnlyMaterializedSchemaB\x0b\n\ttype_argsJ\x04\x08\x07\x10\x08J\x04\x08\x08\x10\tJ\x04\x08\t\x10\nJ\x04\x08\n\x10\x0bJ\x04\x08\x0b\x10\x0cJ\x04\x08\x0c\x10\rJ\x04\x08\r\x10\x0eJ\x04\x08\x10\x10\x11J\x04\x08\x11\x10\x12J\x04\x08\x12\x10\x13J\x04\x08\x13\x10\x14J\x04\x08\x14\x10\x15J\x04\x08\x15\x10\x16J\x04\x08\x16\x10\x17\"f\n\x11\x45ntityKeyOverride\x12\x34\n\tentity_id\x18\x01 \x01(\x0b\x32\x17.tecton_proto.common.IdR\x08\x65ntityId\x12\x1b\n\tjoin_keys\x18\x02 \x03(\tR\x08joinKeys\"K\n\x0e\x42\x61\x63kfillConfig\x12\x39\n\x04mode\x18\x01 \x01(\x0e\x32%.tecton_proto.args.BackfillConfigModeR\x04mode\"\xd9\x07\n\x0cTemporalArgs\x12#\n\rtimestamp_key\x18\x01 \x01(\tR\x0ctimestampKey\x12\x46\n\x11schedule_interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x10scheduleInterval\x12O\n\x12\x66\x65\x61ture_start_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\x92M\x02\x08\x01R\x10\x66\x65\x61tureStartTime\x12^\n\x1emax_batch_aggregation_interval\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x1bmaxBatchAggregationInterval\x12\x41\n\x0bserving_ttl\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationB\x05\x92M\x02\x08\x06R\nservingTtl\x12S\n\x0eoffline_config\x18\x06 \x01(\x0b\x32,.tecton_proto.args.OfflineFeatureStoreConfigR\rofflineConfig\x12U\n\x15\x62\x61tch_materialization\x18\x07 \x01(\x0b\x32 .tecton_proto.args.ClusterConfigR\x14\x62\x61tchMaterialization\x12]\n\x19streaming_materialization\x18\x08 \x01(\x0b\x32 .tecton_proto.args.ClusterConfigR\x18streamingMaterialization\x12J\n\nmonitoring\x18\t \x01(\x0b\x32#.tecton_proto.args.MonitoringConfigB\x05\x92M\x02\x08\x01R\nmonitoring\x12K\n\x10\x64\x61ta_source_type\x18\n \x01(\x0e\x32!.tecton_proto.args.DataSourceTypeR\x0e\x64\x61taSourceType\x12Q\n\x0f\x62\x61\x63kfill_config\x18\x0b \x01(\x0b\x32!.tecton_proto.args.BackfillConfigB\x05\x92M\x02\x08\x03R\x0e\x62\x61\x63kfillConfig\x12T\n\x13online_store_config\x18\x0c \x01(\x0b\x32$.tecton_proto.args.OnlineStoreConfigR\x11onlineStoreConfig\x12\x1b\n\tis_custom\x18\r \x01(\x08R\x08isCustom\"\xa1\x08\n\x15TemporalAggregateArgs\x12k\n!aggregation_slide_period_duration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\x05\x92M\x02\x08\x05R\x1e\x61ggregationSlidePeriodDuration\x12\x38\n\x18\x61ggregation_slide_period\x18\x02 \x01(\tR\x16\x61ggregationSlidePeriod\x12I\n\x0c\x61ggregations\x18\x03 \x03(\x0b\x32%.tecton_proto.args.FeatureAggregationR\x0c\x61ggregations\x12#\n\rtimestamp_key\x18\x04 \x01(\tR\x0ctimestampKey\x12\x46\n\x11schedule_interval\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationR\x10scheduleInterval\x12O\n\x12\x66\x65\x61ture_start_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\x92M\x02\x08\x01R\x10\x66\x65\x61tureStartTime\x12^\n\x1emax_batch_aggregation_interval\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationR\x1bmaxBatchAggregationInterval\x12S\n\x0eoffline_config\x18\x08 \x01(\x0b\x32,.tecton_proto.args.OfflineFeatureStoreConfigR\rofflineConfig\x12U\n\x15\x62\x61tch_materialization\x18\t \x01(\x0b\x32 .tecton_proto.args.ClusterConfigR\x14\x62\x61tchMaterialization\x12]\n\x19streaming_materialization\x18\n \x01(\x0b\x32 .tecton_proto.args.ClusterConfigR\x18streamingMaterialization\x12J\n\nmonitoring\x18\x0b \x01(\x0b\x32#.tecton_proto.args.MonitoringConfigB\x05\x92M\x02\x08\x01R\nmonitoring\x12K\n\x10\x64\x61ta_source_type\x18\x0c \x01(\x0e\x32!.tecton_proto.args.DataSourceTypeR\x0e\x64\x61taSourceType\x12T\n\x13online_store_config\x18\r \x01(\x0b\x32$.tecton_proto.args.OnlineStoreConfigR\x11onlineStoreConfig\"U\n\x0cOnDemandArgs\x12\x45\n\routput_schema\x18\x01 \x01(\x0b\x32 .tecton_proto.common.SparkSchemaR\x0coutputSchema\"\x97\x03\n\x10\x46\x65\x61tureTableArgs\x12\x45\n\routput_schema\x18\x01 \x01(\x0b\x32 .tecton_proto.common.SparkSchemaR\x0coutputSchema\x12:\n\x0bserving_ttl\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\nservingTtl\x12S\n\x0eoffline_config\x18\x03 \x01(\x0b\x32,.tecton_proto.args.OfflineFeatureStoreConfigR\rofflineConfig\x12T\n\x13online_store_config\x18\x04 \x01(\x0b\x32$.tecton_proto.args.OnlineStoreConfigR\x11onlineStoreConfig\x12U\n\x15\x62\x61tch_materialization\x18\x05 \x01(\x0b\x32 .tecton_proto.args.ClusterConfigR\x14\x62\x61tchMaterialization\"\x87\x03\n\x12\x46\x65\x61tureAggregation\x12\x16\n\x06\x63olumn\x18\x01 \x01(\tR\x06\x63olumn\x12\x1a\n\x08\x66unction\x18\x02 \x01(\tR\x08\x66unction\x12\x62\n\x0f\x66unction_params\x18\x05 \x03(\x0b\x32\x39.tecton_proto.args.FeatureAggregation.FunctionParamsEntryR\x0e\x66unctionParams\x12T\n\x15time_window_durations\x18\x03 \x03(\x0b\x32\x19.google.protobuf.DurationB\x05\x92M\x02\x08\x05R\x13timeWindowDurations\x12!\n\x0ctime_windows\x18\x04 \x03(\tR\x0btimeWindows\x1a`\n\x13\x46unctionParamsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32\x1d.tecton_proto.args.ParamValueR\x05value:\x02\x38\x01\"8\n\nParamValue\x12!\n\x0bint64_value\x18\x01 \x01(\x03H\x00R\nint64ValueB\x07\n\x05value\"\x8b\x02\n\rClusterConfig\x12U\n\x10\x65xisting_cluster\x18\x01 \x01(\x0b\x32(.tecton_proto.args.ExistingClusterConfigH\x00R\x0f\x65xistingCluster\x12V\n\x0enew_databricks\x18\x02 \x01(\x0b\x32-.tecton_proto.args.NewDatabricksClusterConfigH\x00R\rnewDatabricks\x12\x41\n\x07new_emr\x18\x03 \x01(\x0b\x32&.tecton_proto.args.NewEMRClusterConfigH\x00R\x06newEmrB\x08\n\x06\x63onfig\"N\n\x15\x45xistingClusterConfig\x12\x35\n\x13\x65xisting_cluster_id\x18\x01 \x01(\tB\x05\x92M\x02\x08\x01R\x11\x65xistingClusterId\"\xa1\x03\n\x1aNewDatabricksClusterConfig\x12*\n\rinstance_type\x18\x01 \x01(\tB\x05\x92M\x02\x08\x01R\x0cinstanceType\x12:\n\x15instance_availability\x18\x06 \x01(\tB\x05\x92M\x02\x08\x01R\x14instanceAvailability\x12\x31\n\x11number_of_workers\x18\x02 \x01(\x05\x42\x05\x92M\x02\x08\x01R\x0fnumberOfWorkers\x12\x39\n\x16root_volume_size_in_gb\x18\x03 \x01(\x05\x42\x05\x92M\x02\x08\x01R\x12rootVolumeSizeInGb\x12\x34\n\x16\x65xtra_pip_dependencies\x18\x04 \x03(\tR\x14\x65xtraPipDependencies\x12H\n\x0cspark_config\x18\x05 \x01(\x0b\x32\x1e.tecton_proto.args.SparkConfigB\x05\x92M\x02\x08\x01R\x0bsparkConfig\x12-\n\x0f\x66irst_on_demand\x18\x07 \x01(\x05\x42\x05\x92M\x02\x08\x01R\rfirstOnDemand\"\x9a\x03\n\x13NewEMRClusterConfig\x12*\n\rinstance_type\x18\x01 \x01(\tB\x05\x92M\x02\x08\x01R\x0cinstanceType\x12:\n\x15instance_availability\x18\x06 \x01(\tB\x05\x92M\x02\x08\x01R\x14instanceAvailability\x12\x31\n\x11number_of_workers\x18\x02 \x01(\x05\x42\x05\x92M\x02\x08\x01R\x0fnumberOfWorkers\x12\x39\n\x16root_volume_size_in_gb\x18\x03 \x01(\x05\x42\x05\x92M\x02\x08\x01R\x12rootVolumeSizeInGb\x12\x34\n\x16\x65xtra_pip_dependencies\x18\x04 \x03(\tR\x14\x65xtraPipDependencies\x12H\n\x0cspark_config\x18\x05 \x01(\x0b\x32\x1e.tecton_proto.args.SparkConfigB\x05\x92M\x02\x08\x01R\x0bsparkConfig\x12-\n\x0f\x66irst_on_demand\x18\x07 \x01(\x05\x42\x05\x92M\x02\x08\x01R\rfirstOnDemand\"\xf7\x01\n\x0bSparkConfig\x12.\n\x13spark_driver_memory\x18\x01 \x01(\tR\x11sparkDriverMemory\x12\x32\n\x15spark_executor_memory\x18\x02 \x01(\tR\x13sparkExecutorMemory\x12?\n\x1cspark_driver_memory_overhead\x18\x03 \x01(\tR\x19sparkDriverMemoryOverhead\x12\x43\n\x1espark_executor_memory_overhead\x18\x04 \x01(\tR\x1bsparkExecutorMemoryOverhead\"\xa0\x01\n\x11OnlineStoreConfig\x12@\n\x06\x64ynamo\x18\x01 \x01(\x0b\x32&.tecton_proto.args.DynamoDbOnlineStoreH\x00R\x06\x64ynamo\x12;\n\x05redis\x18\x02 \x01(\x0b\x32#.tecton_proto.args.RedisOnlineStoreH\x00R\x05redisB\x0c\n\nstore_type\"\xa1\x02\n\x13\x44ynamoDbOnlineStore\x12\x33\n\x16\x63ross_account_role_arn\x18\x01 \x01(\tR\x13\x63rossAccountRoleArn\x12\x39\n\x19\x63ross_account_external_id\x18\x02 \x01(\tR\x16\x63rossAccountExternalId\x12L\n#cross_account_intermediate_role_arn\x18\x05 \x01(\tR\x1f\x63rossAccountIntermediateRoleArn\x12\x18\n\x07\x65nabled\x18\x03 \x01(\x08R\x07\x65nabled\x12\x32\n\x15\x64\x62\x66s_credentials_path\x18\x04 \x01(\tR\x13\x64\x62\x66sCredentialsPath\"\xb7\x01\n\x10RedisOnlineStore\x12)\n\x10primary_endpoint\x18\x02 \x01(\tR\x0fprimaryEndpoint\x12\x31\n\x14\x61uthentication_token\x18\x04 \x01(\tR\x13\x61uthenticationToken\x12\x1f\n\x0btls_enabled\x18\x06 \x01(\x08R\ntlsEnabled\x12\x18\n\x07\x65nabled\x18\x05 \x01(\x08R\x07\x65nabledJ\x04\x08\x01\x10\x02J\x04\x08\x03\x10\x04\"\x9f\x01\n\x19OfflineFeatureStoreConfig\x12<\n\x07parquet\x18\x01 \x01(\x0b\x32 .tecton_proto.args.ParquetConfigH\x00R\x07parquet\x12\x36\n\x05\x64\x65lta\x18\x02 \x01(\x0b\x32\x1e.tecton_proto.args.DeltaConfigH\x00R\x05\x64\x65ltaB\x0c\n\nstore_type\"\x0f\n\rParquetConfig\"X\n\x0b\x44\x65ltaConfig\x12I\n\x13time_partition_size\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\x11timePartitionSize\"\xb9\x01\n\x10MonitoringConfig\x12+\n\x11monitor_freshness\x18\x01 \x01(\x08R\x10monitorFreshness\x12W\n\x1a\x65xpected_feature_freshness\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x18\x65xpectedFeatureFreshness\x12\x1f\n\x0b\x61lert_email\x18\x03 \x01(\tR\nalertEmail*\xc0\x01\n\x0f\x46\x65\x61tureViewType\x12\x1d\n\x19\x46\x45\x41TURE_VIEW_TYPE_UNKNOWN\x10\x00\x12\x1e\n\x1a\x46\x45\x41TURE_VIEW_TYPE_TEMPORAL\x10\x01\x12(\n$FEATURE_VIEW_TYPE_TEMPORAL_AGGREGATE\x10\x02\x12\x1f\n\x1b\x46\x45\x41TURE_VIEW_TYPE_ON_DEMAND\x10\x03\x12#\n\x1f\x46\x45\x41TURE_VIEW_TYPE_FEATURE_TABLE\x10\x04*\xbb\x01\n\x12\x42\x61\x63kfillConfigMode\x12 \n\x1c\x42\x41\x43KFILL_CONFIG_MODE_UNKNOWN\x10\x00\x12?\n;BACKFILL_CONFIG_MODE_SINGLE_BATCH_SCHEDULE_INTERVAL_PER_JOB\x10\x01\x12\x42\n>BACKFILL_CONFIG_MODE_MULTIPLE_BATCH_SCHEDULE_INTERVALS_PER_JOB\x10\x02\x42\x13\n\x0f\x63om.tecton.argsP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,tecton__proto_dot_args_dot_basic__info__pb2.DESCRIPTOR,tecton__proto_dot_args_dot_pipeline__pb2.DESCRIPTOR,tecton__proto_dot_args_dot_diff__options__pb2.DESCRIPTOR,tecton__proto_dot_args_dot_virtual__data__source__pb2.DESCRIPTOR,tecton__proto_dot_common_dot_id__pb2.DESCRIPTOR,tecton__proto_dot_common_dot_spark__schema__pb2.DESCRIPTOR,])

_FEATUREVIEWTYPE = _descriptor.EnumDescriptor(
  name='FeatureViewType',
  full_name='tecton_proto.args.FeatureViewType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FEATURE_VIEW_TYPE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_VIEW_TYPE_TEMPORAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_VIEW_TYPE_TEMPORAL_AGGREGATE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_VIEW_TYPE_ON_DEMAND', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURE_VIEW_TYPE_FEATURE_TABLE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7206,
  serialized_end=7398,
)
_sym_db.RegisterEnumDescriptor(_FEATUREVIEWTYPE)

FeatureViewType = enum_type_wrapper.EnumTypeWrapper(_FEATUREVIEWTYPE)
_BACKFILLCONFIGMODE = _descriptor.EnumDescriptor(
  name='BackfillConfigMode',
  full_name='tecton_proto.args.BackfillConfigMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BACKFILL_CONFIG_MODE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BACKFILL_CONFIG_MODE_SINGLE_BATCH_SCHEDULE_INTERVAL_PER_JOB', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BACKFILL_CONFIG_MODE_MULTIPLE_BATCH_SCHEDULE_INTERVALS_PER_JOB', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7401,
  serialized_end=7588,
)
_sym_db.RegisterEnumDescriptor(_BACKFILLCONFIGMODE)

BackfillConfigMode = enum_type_wrapper.EnumTypeWrapper(_BACKFILLCONFIGMODE)
FEATURE_VIEW_TYPE_UNKNOWN = 0
FEATURE_VIEW_TYPE_TEMPORAL = 1
FEATURE_VIEW_TYPE_TEMPORAL_AGGREGATE = 2
FEATURE_VIEW_TYPE_ON_DEMAND = 3
FEATURE_VIEW_TYPE_FEATURE_TABLE = 4
BACKFILL_CONFIG_MODE_UNKNOWN = 0
BACKFILL_CONFIG_MODE_SINGLE_BATCH_SCHEDULE_INTERVAL_PER_JOB = 1
BACKFILL_CONFIG_MODE_MULTIPLE_BATCH_SCHEDULE_INTERVALS_PER_JOB = 2



_FEATUREVIEWARGS = _descriptor.Descriptor(
  name='FeatureViewArgs',
  full_name='tecton_proto.args.FeatureViewArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feature_view_id', full_name='tecton_proto.args.FeatureViewArgs.feature_view_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureViewId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_view_type', full_name='tecton_proto.args.FeatureViewArgs.feature_view_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureViewType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='info', full_name='tecton_proto.args.FeatureViewArgs.info', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\020\001', json_name='info', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entities', full_name='tecton_proto.args.FeatureViewArgs.entities', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='entities', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temporal_args', full_name='tecton_proto.args.FeatureViewArgs.temporal_args', index=4,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='temporalArgs', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temporal_aggregate_args', full_name='tecton_proto.args.FeatureViewArgs.temporal_aggregate_args', index=5,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='temporalAggregateArgs', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='on_demand_args', full_name='tecton_proto.args.FeatureViewArgs.on_demand_args', index=6,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='onDemandArgs', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_table_args', full_name='tecton_proto.args.FeatureViewArgs.feature_table_args', index=7,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='featureTableArgs', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='framework_version', full_name='tecton_proto.args.FeatureViewArgs.framework_version', index=8,
      number=27, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='frameworkVersion', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online_serving_index', full_name='tecton_proto.args.FeatureViewArgs.online_serving_index', index=9,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='onlineServingIndex', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online_enabled', full_name='tecton_proto.args.FeatureViewArgs.online_enabled', index=10,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\001', json_name='onlineEnabled', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offline_enabled', full_name='tecton_proto.args.FeatureViewArgs.offline_enabled', index=11,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\001', json_name='offlineEnabled', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pipeline', full_name='tecton_proto.args.FeatureViewArgs.pipeline', index=12,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pipeline', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='test_only_view_schema', full_name='tecton_proto.args.FeatureViewArgs.test_only_view_schema', index=13,
      number=1000, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='testOnlyViewSchema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='test_only_materialized_schema', full_name='tecton_proto.args.FeatureViewArgs.test_only_materialized_schema', index=14,
      number=1001, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='testOnlyMaterializedSchema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='type_args', full_name='tecton_proto.args.FeatureViewArgs.type_args',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=348,
  serialized_end=1494,
)


_ENTITYKEYOVERRIDE = _descriptor.Descriptor(
  name='EntityKeyOverride',
  full_name='tecton_proto.args.EntityKeyOverride',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entity_id', full_name='tecton_proto.args.EntityKeyOverride.entity_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='entityId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='join_keys', full_name='tecton_proto.args.EntityKeyOverride.join_keys', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='joinKeys', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1496,
  serialized_end=1598,
)


_BACKFILLCONFIG = _descriptor.Descriptor(
  name='BackfillConfig',
  full_name='tecton_proto.args.BackfillConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='tecton_proto.args.BackfillConfig.mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='mode', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1600,
  serialized_end=1675,
)


_TEMPORALARGS = _descriptor.Descriptor(
  name='TemporalArgs',
  full_name='tecton_proto.args.TemporalArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp_key', full_name='tecton_proto.args.TemporalArgs.timestamp_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestampKey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schedule_interval', full_name='tecton_proto.args.TemporalArgs.schedule_interval', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='scheduleInterval', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_start_time', full_name='tecton_proto.args.TemporalArgs.feature_start_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\001', json_name='featureStartTime', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_batch_aggregation_interval', full_name='tecton_proto.args.TemporalArgs.max_batch_aggregation_interval', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='maxBatchAggregationInterval', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serving_ttl', full_name='tecton_proto.args.TemporalArgs.serving_ttl', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\006', json_name='servingTtl', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offline_config', full_name='tecton_proto.args.TemporalArgs.offline_config', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='offlineConfig', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_materialization', full_name='tecton_proto.args.TemporalArgs.batch_materialization', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='batchMaterialization', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='streaming_materialization', full_name='tecton_proto.args.TemporalArgs.streaming_materialization', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='streamingMaterialization', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='monitoring', full_name='tecton_proto.args.TemporalArgs.monitoring', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\001', json_name='monitoring', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_source_type', full_name='tecton_proto.args.TemporalArgs.data_source_type', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dataSourceType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backfill_config', full_name='tecton_proto.args.TemporalArgs.backfill_config', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\003', json_name='backfillConfig', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online_store_config', full_name='tecton_proto.args.TemporalArgs.online_store_config', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='onlineStoreConfig', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_custom', full_name='tecton_proto.args.TemporalArgs.is_custom', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='isCustom', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1678,
  serialized_end=2663,
)


_TEMPORALAGGREGATEARGS = _descriptor.Descriptor(
  name='TemporalAggregateArgs',
  full_name='tecton_proto.args.TemporalAggregateArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='aggregation_slide_period_duration', full_name='tecton_proto.args.TemporalAggregateArgs.aggregation_slide_period_duration', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\005', json_name='aggregationSlidePeriodDuration', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aggregation_slide_period', full_name='tecton_proto.args.TemporalAggregateArgs.aggregation_slide_period', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='aggregationSlidePeriod', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aggregations', full_name='tecton_proto.args.TemporalAggregateArgs.aggregations', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='aggregations', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp_key', full_name='tecton_proto.args.TemporalAggregateArgs.timestamp_key', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestampKey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schedule_interval', full_name='tecton_proto.args.TemporalAggregateArgs.schedule_interval', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='scheduleInterval', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feature_start_time', full_name='tecton_proto.args.TemporalAggregateArgs.feature_start_time', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\001', json_name='featureStartTime', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_batch_aggregation_interval', full_name='tecton_proto.args.TemporalAggregateArgs.max_batch_aggregation_interval', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='maxBatchAggregationInterval', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offline_config', full_name='tecton_proto.args.TemporalAggregateArgs.offline_config', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='offlineConfig', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_materialization', full_name='tecton_proto.args.TemporalAggregateArgs.batch_materialization', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='batchMaterialization', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='streaming_materialization', full_name='tecton_proto.args.TemporalAggregateArgs.streaming_materialization', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='streamingMaterialization', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='monitoring', full_name='tecton_proto.args.TemporalAggregateArgs.monitoring', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\001', json_name='monitoring', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_source_type', full_name='tecton_proto.args.TemporalAggregateArgs.data_source_type', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dataSourceType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online_store_config', full_name='tecton_proto.args.TemporalAggregateArgs.online_store_config', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='onlineStoreConfig', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2666,
  serialized_end=3723,
)


_ONDEMANDARGS = _descriptor.Descriptor(
  name='OnDemandArgs',
  full_name='tecton_proto.args.OnDemandArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='output_schema', full_name='tecton_proto.args.OnDemandArgs.output_schema', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='outputSchema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3725,
  serialized_end=3810,
)


_FEATURETABLEARGS = _descriptor.Descriptor(
  name='FeatureTableArgs',
  full_name='tecton_proto.args.FeatureTableArgs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='output_schema', full_name='tecton_proto.args.FeatureTableArgs.output_schema', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='outputSchema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serving_ttl', full_name='tecton_proto.args.FeatureTableArgs.serving_ttl', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='servingTtl', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offline_config', full_name='tecton_proto.args.FeatureTableArgs.offline_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='offlineConfig', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online_store_config', full_name='tecton_proto.args.FeatureTableArgs.online_store_config', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='onlineStoreConfig', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_materialization', full_name='tecton_proto.args.FeatureTableArgs.batch_materialization', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='batchMaterialization', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3813,
  serialized_end=4220,
)


_FEATUREAGGREGATION_FUNCTIONPARAMSENTRY = _descriptor.Descriptor(
  name='FunctionParamsEntry',
  full_name='tecton_proto.args.FeatureAggregation.FunctionParamsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='tecton_proto.args.FeatureAggregation.FunctionParamsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='tecton_proto.args.FeatureAggregation.FunctionParamsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4518,
  serialized_end=4614,
)

_FEATUREAGGREGATION = _descriptor.Descriptor(
  name='FeatureAggregation',
  full_name='tecton_proto.args.FeatureAggregation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='column', full_name='tecton_proto.args.FeatureAggregation.column', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='column', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='function', full_name='tecton_proto.args.FeatureAggregation.function', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='function', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='function_params', full_name='tecton_proto.args.FeatureAggregation.function_params', index=2,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='functionParams', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_window_durations', full_name='tecton_proto.args.FeatureAggregation.time_window_durations', index=3,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\005', json_name='timeWindowDurations', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_windows', full_name='tecton_proto.args.FeatureAggregation.time_windows', index=4,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timeWindows', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FEATUREAGGREGATION_FUNCTIONPARAMSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4223,
  serialized_end=4614,
)


_PARAMVALUE = _descriptor.Descriptor(
  name='ParamValue',
  full_name='tecton_proto.args.ParamValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='int64_value', full_name='tecton_proto.args.ParamValue.int64_value', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='int64Value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='tecton_proto.args.ParamValue.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4616,
  serialized_end=4672,
)


_CLUSTERCONFIG = _descriptor.Descriptor(
  name='ClusterConfig',
  full_name='tecton_proto.args.ClusterConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='existing_cluster', full_name='tecton_proto.args.ClusterConfig.existing_cluster', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='existingCluster', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_databricks', full_name='tecton_proto.args.ClusterConfig.new_databricks', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='newDatabricks', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_emr', full_name='tecton_proto.args.ClusterConfig.new_emr', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='newEmr', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config', full_name='tecton_proto.args.ClusterConfig.config',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4675,
  serialized_end=4942,
)


_EXISTINGCLUSTERCONFIG = _descriptor.Descriptor(
  name='ExistingClusterConfig',
  full_name='tecton_proto.args.ExistingClusterConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='existing_cluster_id', full_name='tecton_proto.args.ExistingClusterConfig.existing_cluster_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\001', json_name='existingClusterId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4944,
  serialized_end=5022,
)


_NEWDATABRICKSCLUSTERCONFIG = _descriptor.Descriptor(
  name='NewDatabricksClusterConfig',
  full_name='tecton_proto.args.NewDatabricksClusterConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_type', full_name='tecton_proto.args.NewDatabricksClusterConfig.instance_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\001', json_name='instanceType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instance_availability', full_name='tecton_proto.args.NewDatabricksClusterConfig.instance_availability', index=1,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\001', json_name='instanceAvailability', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number_of_workers', full_name='tecton_proto.args.NewDatabricksClusterConfig.number_of_workers', index=2,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\001', json_name='numberOfWorkers', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='root_volume_size_in_gb', full_name='tecton_proto.args.NewDatabricksClusterConfig.root_volume_size_in_gb', index=3,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\001', json_name='rootVolumeSizeInGb', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extra_pip_dependencies', full_name='tecton_proto.args.NewDatabricksClusterConfig.extra_pip_dependencies', index=4,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='extraPipDependencies', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spark_config', full_name='tecton_proto.args.NewDatabricksClusterConfig.spark_config', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\001', json_name='sparkConfig', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='first_on_demand', full_name='tecton_proto.args.NewDatabricksClusterConfig.first_on_demand', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\001', json_name='firstOnDemand', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5025,
  serialized_end=5442,
)


_NEWEMRCLUSTERCONFIG = _descriptor.Descriptor(
  name='NewEMRClusterConfig',
  full_name='tecton_proto.args.NewEMRClusterConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_type', full_name='tecton_proto.args.NewEMRClusterConfig.instance_type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\001', json_name='instanceType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instance_availability', full_name='tecton_proto.args.NewEMRClusterConfig.instance_availability', index=1,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\001', json_name='instanceAvailability', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number_of_workers', full_name='tecton_proto.args.NewEMRClusterConfig.number_of_workers', index=2,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\001', json_name='numberOfWorkers', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='root_volume_size_in_gb', full_name='tecton_proto.args.NewEMRClusterConfig.root_volume_size_in_gb', index=3,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\001', json_name='rootVolumeSizeInGb', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extra_pip_dependencies', full_name='tecton_proto.args.NewEMRClusterConfig.extra_pip_dependencies', index=4,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='extraPipDependencies', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spark_config', full_name='tecton_proto.args.NewEMRClusterConfig.spark_config', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\001', json_name='sparkConfig', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='first_on_demand', full_name='tecton_proto.args.NewEMRClusterConfig.first_on_demand', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\222M\002\010\001', json_name='firstOnDemand', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5445,
  serialized_end=5855,
)


_SPARKCONFIG = _descriptor.Descriptor(
  name='SparkConfig',
  full_name='tecton_proto.args.SparkConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='spark_driver_memory', full_name='tecton_proto.args.SparkConfig.spark_driver_memory', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sparkDriverMemory', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spark_executor_memory', full_name='tecton_proto.args.SparkConfig.spark_executor_memory', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sparkExecutorMemory', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spark_driver_memory_overhead', full_name='tecton_proto.args.SparkConfig.spark_driver_memory_overhead', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sparkDriverMemoryOverhead', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spark_executor_memory_overhead', full_name='tecton_proto.args.SparkConfig.spark_executor_memory_overhead', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sparkExecutorMemoryOverhead', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5858,
  serialized_end=6105,
)


_ONLINESTORECONFIG = _descriptor.Descriptor(
  name='OnlineStoreConfig',
  full_name='tecton_proto.args.OnlineStoreConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dynamo', full_name='tecton_proto.args.OnlineStoreConfig.dynamo', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dynamo', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redis', full_name='tecton_proto.args.OnlineStoreConfig.redis', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='redis', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='store_type', full_name='tecton_proto.args.OnlineStoreConfig.store_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=6108,
  serialized_end=6268,
)


_DYNAMODBONLINESTORE = _descriptor.Descriptor(
  name='DynamoDbOnlineStore',
  full_name='tecton_proto.args.DynamoDbOnlineStore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cross_account_role_arn', full_name='tecton_proto.args.DynamoDbOnlineStore.cross_account_role_arn', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='crossAccountRoleArn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cross_account_external_id', full_name='tecton_proto.args.DynamoDbOnlineStore.cross_account_external_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='crossAccountExternalId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cross_account_intermediate_role_arn', full_name='tecton_proto.args.DynamoDbOnlineStore.cross_account_intermediate_role_arn', index=2,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='crossAccountIntermediateRoleArn', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='tecton_proto.args.DynamoDbOnlineStore.enabled', index=3,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='enabled', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dbfs_credentials_path', full_name='tecton_proto.args.DynamoDbOnlineStore.dbfs_credentials_path', index=4,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dbfsCredentialsPath', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6271,
  serialized_end=6560,
)


_REDISONLINESTORE = _descriptor.Descriptor(
  name='RedisOnlineStore',
  full_name='tecton_proto.args.RedisOnlineStore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='primary_endpoint', full_name='tecton_proto.args.RedisOnlineStore.primary_endpoint', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='primaryEndpoint', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authentication_token', full_name='tecton_proto.args.RedisOnlineStore.authentication_token', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='authenticationToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tls_enabled', full_name='tecton_proto.args.RedisOnlineStore.tls_enabled', index=2,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='tlsEnabled', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='tecton_proto.args.RedisOnlineStore.enabled', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='enabled', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6563,
  serialized_end=6746,
)


_OFFLINEFEATURESTORECONFIG = _descriptor.Descriptor(
  name='OfflineFeatureStoreConfig',
  full_name='tecton_proto.args.OfflineFeatureStoreConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parquet', full_name='tecton_proto.args.OfflineFeatureStoreConfig.parquet', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='parquet', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delta', full_name='tecton_proto.args.OfflineFeatureStoreConfig.delta', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='delta', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='store_type', full_name='tecton_proto.args.OfflineFeatureStoreConfig.store_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=6749,
  serialized_end=6908,
)


_PARQUETCONFIG = _descriptor.Descriptor(
  name='ParquetConfig',
  full_name='tecton_proto.args.ParquetConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6910,
  serialized_end=6925,
)


_DELTACONFIG = _descriptor.Descriptor(
  name='DeltaConfig',
  full_name='tecton_proto.args.DeltaConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='time_partition_size', full_name='tecton_proto.args.DeltaConfig.time_partition_size', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timePartitionSize', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6927,
  serialized_end=7015,
)


_MONITORINGCONFIG = _descriptor.Descriptor(
  name='MonitoringConfig',
  full_name='tecton_proto.args.MonitoringConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='monitor_freshness', full_name='tecton_proto.args.MonitoringConfig.monitor_freshness', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='monitorFreshness', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expected_feature_freshness', full_name='tecton_proto.args.MonitoringConfig.expected_feature_freshness', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='expectedFeatureFreshness', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alert_email', full_name='tecton_proto.args.MonitoringConfig.alert_email', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='alertEmail', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7018,
  serialized_end=7203,
)

_FEATUREVIEWARGS.fields_by_name['feature_view_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_FEATUREVIEWARGS.fields_by_name['feature_view_type'].enum_type = _FEATUREVIEWTYPE
_FEATUREVIEWARGS.fields_by_name['info'].message_type = tecton__proto_dot_args_dot_basic__info__pb2._BASICINFO
_FEATUREVIEWARGS.fields_by_name['entities'].message_type = _ENTITYKEYOVERRIDE
_FEATUREVIEWARGS.fields_by_name['temporal_args'].message_type = _TEMPORALARGS
_FEATUREVIEWARGS.fields_by_name['temporal_aggregate_args'].message_type = _TEMPORALAGGREGATEARGS
_FEATUREVIEWARGS.fields_by_name['on_demand_args'].message_type = _ONDEMANDARGS
_FEATUREVIEWARGS.fields_by_name['feature_table_args'].message_type = _FEATURETABLEARGS
_FEATUREVIEWARGS.fields_by_name['pipeline'].message_type = tecton__proto_dot_args_dot_pipeline__pb2._PIPELINE
_FEATUREVIEWARGS.fields_by_name['test_only_view_schema'].message_type = tecton__proto_dot_common_dot_spark__schema__pb2._SPARKSCHEMA
_FEATUREVIEWARGS.fields_by_name['test_only_materialized_schema'].message_type = tecton__proto_dot_common_dot_spark__schema__pb2._SPARKSCHEMA
_FEATUREVIEWARGS.oneofs_by_name['type_args'].fields.append(
  _FEATUREVIEWARGS.fields_by_name['temporal_args'])
_FEATUREVIEWARGS.fields_by_name['temporal_args'].containing_oneof = _FEATUREVIEWARGS.oneofs_by_name['type_args']
_FEATUREVIEWARGS.oneofs_by_name['type_args'].fields.append(
  _FEATUREVIEWARGS.fields_by_name['temporal_aggregate_args'])
_FEATUREVIEWARGS.fields_by_name['temporal_aggregate_args'].containing_oneof = _FEATUREVIEWARGS.oneofs_by_name['type_args']
_FEATUREVIEWARGS.oneofs_by_name['type_args'].fields.append(
  _FEATUREVIEWARGS.fields_by_name['on_demand_args'])
_FEATUREVIEWARGS.fields_by_name['on_demand_args'].containing_oneof = _FEATUREVIEWARGS.oneofs_by_name['type_args']
_FEATUREVIEWARGS.oneofs_by_name['type_args'].fields.append(
  _FEATUREVIEWARGS.fields_by_name['feature_table_args'])
_FEATUREVIEWARGS.fields_by_name['feature_table_args'].containing_oneof = _FEATUREVIEWARGS.oneofs_by_name['type_args']
_ENTITYKEYOVERRIDE.fields_by_name['entity_id'].message_type = tecton__proto_dot_common_dot_id__pb2._ID
_BACKFILLCONFIG.fields_by_name['mode'].enum_type = _BACKFILLCONFIGMODE
_TEMPORALARGS.fields_by_name['schedule_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_TEMPORALARGS.fields_by_name['feature_start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TEMPORALARGS.fields_by_name['max_batch_aggregation_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_TEMPORALARGS.fields_by_name['serving_ttl'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_TEMPORALARGS.fields_by_name['offline_config'].message_type = _OFFLINEFEATURESTORECONFIG
_TEMPORALARGS.fields_by_name['batch_materialization'].message_type = _CLUSTERCONFIG
_TEMPORALARGS.fields_by_name['streaming_materialization'].message_type = _CLUSTERCONFIG
_TEMPORALARGS.fields_by_name['monitoring'].message_type = _MONITORINGCONFIG
_TEMPORALARGS.fields_by_name['data_source_type'].enum_type = tecton__proto_dot_args_dot_virtual__data__source__pb2._DATASOURCETYPE
_TEMPORALARGS.fields_by_name['backfill_config'].message_type = _BACKFILLCONFIG
_TEMPORALARGS.fields_by_name['online_store_config'].message_type = _ONLINESTORECONFIG
_TEMPORALAGGREGATEARGS.fields_by_name['aggregation_slide_period_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_TEMPORALAGGREGATEARGS.fields_by_name['aggregations'].message_type = _FEATUREAGGREGATION
_TEMPORALAGGREGATEARGS.fields_by_name['schedule_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_TEMPORALAGGREGATEARGS.fields_by_name['feature_start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TEMPORALAGGREGATEARGS.fields_by_name['max_batch_aggregation_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_TEMPORALAGGREGATEARGS.fields_by_name['offline_config'].message_type = _OFFLINEFEATURESTORECONFIG
_TEMPORALAGGREGATEARGS.fields_by_name['batch_materialization'].message_type = _CLUSTERCONFIG
_TEMPORALAGGREGATEARGS.fields_by_name['streaming_materialization'].message_type = _CLUSTERCONFIG
_TEMPORALAGGREGATEARGS.fields_by_name['monitoring'].message_type = _MONITORINGCONFIG
_TEMPORALAGGREGATEARGS.fields_by_name['data_source_type'].enum_type = tecton__proto_dot_args_dot_virtual__data__source__pb2._DATASOURCETYPE
_TEMPORALAGGREGATEARGS.fields_by_name['online_store_config'].message_type = _ONLINESTORECONFIG
_ONDEMANDARGS.fields_by_name['output_schema'].message_type = tecton__proto_dot_common_dot_spark__schema__pb2._SPARKSCHEMA
_FEATURETABLEARGS.fields_by_name['output_schema'].message_type = tecton__proto_dot_common_dot_spark__schema__pb2._SPARKSCHEMA
_FEATURETABLEARGS.fields_by_name['serving_ttl'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_FEATURETABLEARGS.fields_by_name['offline_config'].message_type = _OFFLINEFEATURESTORECONFIG
_FEATURETABLEARGS.fields_by_name['online_store_config'].message_type = _ONLINESTORECONFIG
_FEATURETABLEARGS.fields_by_name['batch_materialization'].message_type = _CLUSTERCONFIG
_FEATUREAGGREGATION_FUNCTIONPARAMSENTRY.fields_by_name['value'].message_type = _PARAMVALUE
_FEATUREAGGREGATION_FUNCTIONPARAMSENTRY.containing_type = _FEATUREAGGREGATION
_FEATUREAGGREGATION.fields_by_name['function_params'].message_type = _FEATUREAGGREGATION_FUNCTIONPARAMSENTRY
_FEATUREAGGREGATION.fields_by_name['time_window_durations'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_PARAMVALUE.oneofs_by_name['value'].fields.append(
  _PARAMVALUE.fields_by_name['int64_value'])
_PARAMVALUE.fields_by_name['int64_value'].containing_oneof = _PARAMVALUE.oneofs_by_name['value']
_CLUSTERCONFIG.fields_by_name['existing_cluster'].message_type = _EXISTINGCLUSTERCONFIG
_CLUSTERCONFIG.fields_by_name['new_databricks'].message_type = _NEWDATABRICKSCLUSTERCONFIG
_CLUSTERCONFIG.fields_by_name['new_emr'].message_type = _NEWEMRCLUSTERCONFIG
_CLUSTERCONFIG.oneofs_by_name['config'].fields.append(
  _CLUSTERCONFIG.fields_by_name['existing_cluster'])
_CLUSTERCONFIG.fields_by_name['existing_cluster'].containing_oneof = _CLUSTERCONFIG.oneofs_by_name['config']
_CLUSTERCONFIG.oneofs_by_name['config'].fields.append(
  _CLUSTERCONFIG.fields_by_name['new_databricks'])
_CLUSTERCONFIG.fields_by_name['new_databricks'].containing_oneof = _CLUSTERCONFIG.oneofs_by_name['config']
_CLUSTERCONFIG.oneofs_by_name['config'].fields.append(
  _CLUSTERCONFIG.fields_by_name['new_emr'])
_CLUSTERCONFIG.fields_by_name['new_emr'].containing_oneof = _CLUSTERCONFIG.oneofs_by_name['config']
_NEWDATABRICKSCLUSTERCONFIG.fields_by_name['spark_config'].message_type = _SPARKCONFIG
_NEWEMRCLUSTERCONFIG.fields_by_name['spark_config'].message_type = _SPARKCONFIG
_ONLINESTORECONFIG.fields_by_name['dynamo'].message_type = _DYNAMODBONLINESTORE
_ONLINESTORECONFIG.fields_by_name['redis'].message_type = _REDISONLINESTORE
_ONLINESTORECONFIG.oneofs_by_name['store_type'].fields.append(
  _ONLINESTORECONFIG.fields_by_name['dynamo'])
_ONLINESTORECONFIG.fields_by_name['dynamo'].containing_oneof = _ONLINESTORECONFIG.oneofs_by_name['store_type']
_ONLINESTORECONFIG.oneofs_by_name['store_type'].fields.append(
  _ONLINESTORECONFIG.fields_by_name['redis'])
_ONLINESTORECONFIG.fields_by_name['redis'].containing_oneof = _ONLINESTORECONFIG.oneofs_by_name['store_type']
_OFFLINEFEATURESTORECONFIG.fields_by_name['parquet'].message_type = _PARQUETCONFIG
_OFFLINEFEATURESTORECONFIG.fields_by_name['delta'].message_type = _DELTACONFIG
_OFFLINEFEATURESTORECONFIG.oneofs_by_name['store_type'].fields.append(
  _OFFLINEFEATURESTORECONFIG.fields_by_name['parquet'])
_OFFLINEFEATURESTORECONFIG.fields_by_name['parquet'].containing_oneof = _OFFLINEFEATURESTORECONFIG.oneofs_by_name['store_type']
_OFFLINEFEATURESTORECONFIG.oneofs_by_name['store_type'].fields.append(
  _OFFLINEFEATURESTORECONFIG.fields_by_name['delta'])
_OFFLINEFEATURESTORECONFIG.fields_by_name['delta'].containing_oneof = _OFFLINEFEATURESTORECONFIG.oneofs_by_name['store_type']
_DELTACONFIG.fields_by_name['time_partition_size'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_MONITORINGCONFIG.fields_by_name['expected_feature_freshness'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['FeatureViewArgs'] = _FEATUREVIEWARGS
DESCRIPTOR.message_types_by_name['EntityKeyOverride'] = _ENTITYKEYOVERRIDE
DESCRIPTOR.message_types_by_name['BackfillConfig'] = _BACKFILLCONFIG
DESCRIPTOR.message_types_by_name['TemporalArgs'] = _TEMPORALARGS
DESCRIPTOR.message_types_by_name['TemporalAggregateArgs'] = _TEMPORALAGGREGATEARGS
DESCRIPTOR.message_types_by_name['OnDemandArgs'] = _ONDEMANDARGS
DESCRIPTOR.message_types_by_name['FeatureTableArgs'] = _FEATURETABLEARGS
DESCRIPTOR.message_types_by_name['FeatureAggregation'] = _FEATUREAGGREGATION
DESCRIPTOR.message_types_by_name['ParamValue'] = _PARAMVALUE
DESCRIPTOR.message_types_by_name['ClusterConfig'] = _CLUSTERCONFIG
DESCRIPTOR.message_types_by_name['ExistingClusterConfig'] = _EXISTINGCLUSTERCONFIG
DESCRIPTOR.message_types_by_name['NewDatabricksClusterConfig'] = _NEWDATABRICKSCLUSTERCONFIG
DESCRIPTOR.message_types_by_name['NewEMRClusterConfig'] = _NEWEMRCLUSTERCONFIG
DESCRIPTOR.message_types_by_name['SparkConfig'] = _SPARKCONFIG
DESCRIPTOR.message_types_by_name['OnlineStoreConfig'] = _ONLINESTORECONFIG
DESCRIPTOR.message_types_by_name['DynamoDbOnlineStore'] = _DYNAMODBONLINESTORE
DESCRIPTOR.message_types_by_name['RedisOnlineStore'] = _REDISONLINESTORE
DESCRIPTOR.message_types_by_name['OfflineFeatureStoreConfig'] = _OFFLINEFEATURESTORECONFIG
DESCRIPTOR.message_types_by_name['ParquetConfig'] = _PARQUETCONFIG
DESCRIPTOR.message_types_by_name['DeltaConfig'] = _DELTACONFIG
DESCRIPTOR.message_types_by_name['MonitoringConfig'] = _MONITORINGCONFIG
DESCRIPTOR.enum_types_by_name['FeatureViewType'] = _FEATUREVIEWTYPE
DESCRIPTOR.enum_types_by_name['BackfillConfigMode'] = _BACKFILLCONFIGMODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeatureViewArgs = _reflection.GeneratedProtocolMessageType('FeatureViewArgs', (_message.Message,), {
  'DESCRIPTOR' : _FEATUREVIEWARGS,
  '__module__' : 'tecton_proto.args.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.FeatureViewArgs)
  })
_sym_db.RegisterMessage(FeatureViewArgs)

EntityKeyOverride = _reflection.GeneratedProtocolMessageType('EntityKeyOverride', (_message.Message,), {
  'DESCRIPTOR' : _ENTITYKEYOVERRIDE,
  '__module__' : 'tecton_proto.args.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.EntityKeyOverride)
  })
_sym_db.RegisterMessage(EntityKeyOverride)

BackfillConfig = _reflection.GeneratedProtocolMessageType('BackfillConfig', (_message.Message,), {
  'DESCRIPTOR' : _BACKFILLCONFIG,
  '__module__' : 'tecton_proto.args.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.BackfillConfig)
  })
_sym_db.RegisterMessage(BackfillConfig)

TemporalArgs = _reflection.GeneratedProtocolMessageType('TemporalArgs', (_message.Message,), {
  'DESCRIPTOR' : _TEMPORALARGS,
  '__module__' : 'tecton_proto.args.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.TemporalArgs)
  })
_sym_db.RegisterMessage(TemporalArgs)

TemporalAggregateArgs = _reflection.GeneratedProtocolMessageType('TemporalAggregateArgs', (_message.Message,), {
  'DESCRIPTOR' : _TEMPORALAGGREGATEARGS,
  '__module__' : 'tecton_proto.args.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.TemporalAggregateArgs)
  })
_sym_db.RegisterMessage(TemporalAggregateArgs)

OnDemandArgs = _reflection.GeneratedProtocolMessageType('OnDemandArgs', (_message.Message,), {
  'DESCRIPTOR' : _ONDEMANDARGS,
  '__module__' : 'tecton_proto.args.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.OnDemandArgs)
  })
_sym_db.RegisterMessage(OnDemandArgs)

FeatureTableArgs = _reflection.GeneratedProtocolMessageType('FeatureTableArgs', (_message.Message,), {
  'DESCRIPTOR' : _FEATURETABLEARGS,
  '__module__' : 'tecton_proto.args.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.FeatureTableArgs)
  })
_sym_db.RegisterMessage(FeatureTableArgs)

FeatureAggregation = _reflection.GeneratedProtocolMessageType('FeatureAggregation', (_message.Message,), {

  'FunctionParamsEntry' : _reflection.GeneratedProtocolMessageType('FunctionParamsEntry', (_message.Message,), {
    'DESCRIPTOR' : _FEATUREAGGREGATION_FUNCTIONPARAMSENTRY,
    '__module__' : 'tecton_proto.args.feature_view_pb2'
    # @@protoc_insertion_point(class_scope:tecton_proto.args.FeatureAggregation.FunctionParamsEntry)
    })
  ,
  'DESCRIPTOR' : _FEATUREAGGREGATION,
  '__module__' : 'tecton_proto.args.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.FeatureAggregation)
  })
_sym_db.RegisterMessage(FeatureAggregation)
_sym_db.RegisterMessage(FeatureAggregation.FunctionParamsEntry)

ParamValue = _reflection.GeneratedProtocolMessageType('ParamValue', (_message.Message,), {
  'DESCRIPTOR' : _PARAMVALUE,
  '__module__' : 'tecton_proto.args.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.ParamValue)
  })
_sym_db.RegisterMessage(ParamValue)

ClusterConfig = _reflection.GeneratedProtocolMessageType('ClusterConfig', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERCONFIG,
  '__module__' : 'tecton_proto.args.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.ClusterConfig)
  })
_sym_db.RegisterMessage(ClusterConfig)

ExistingClusterConfig = _reflection.GeneratedProtocolMessageType('ExistingClusterConfig', (_message.Message,), {
  'DESCRIPTOR' : _EXISTINGCLUSTERCONFIG,
  '__module__' : 'tecton_proto.args.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.ExistingClusterConfig)
  })
_sym_db.RegisterMessage(ExistingClusterConfig)

NewDatabricksClusterConfig = _reflection.GeneratedProtocolMessageType('NewDatabricksClusterConfig', (_message.Message,), {
  'DESCRIPTOR' : _NEWDATABRICKSCLUSTERCONFIG,
  '__module__' : 'tecton_proto.args.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.NewDatabricksClusterConfig)
  })
_sym_db.RegisterMessage(NewDatabricksClusterConfig)

NewEMRClusterConfig = _reflection.GeneratedProtocolMessageType('NewEMRClusterConfig', (_message.Message,), {
  'DESCRIPTOR' : _NEWEMRCLUSTERCONFIG,
  '__module__' : 'tecton_proto.args.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.NewEMRClusterConfig)
  })
_sym_db.RegisterMessage(NewEMRClusterConfig)

SparkConfig = _reflection.GeneratedProtocolMessageType('SparkConfig', (_message.Message,), {
  'DESCRIPTOR' : _SPARKCONFIG,
  '__module__' : 'tecton_proto.args.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.SparkConfig)
  })
_sym_db.RegisterMessage(SparkConfig)

OnlineStoreConfig = _reflection.GeneratedProtocolMessageType('OnlineStoreConfig', (_message.Message,), {
  'DESCRIPTOR' : _ONLINESTORECONFIG,
  '__module__' : 'tecton_proto.args.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.OnlineStoreConfig)
  })
_sym_db.RegisterMessage(OnlineStoreConfig)

DynamoDbOnlineStore = _reflection.GeneratedProtocolMessageType('DynamoDbOnlineStore', (_message.Message,), {
  'DESCRIPTOR' : _DYNAMODBONLINESTORE,
  '__module__' : 'tecton_proto.args.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.DynamoDbOnlineStore)
  })
_sym_db.RegisterMessage(DynamoDbOnlineStore)

RedisOnlineStore = _reflection.GeneratedProtocolMessageType('RedisOnlineStore', (_message.Message,), {
  'DESCRIPTOR' : _REDISONLINESTORE,
  '__module__' : 'tecton_proto.args.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.RedisOnlineStore)
  })
_sym_db.RegisterMessage(RedisOnlineStore)

OfflineFeatureStoreConfig = _reflection.GeneratedProtocolMessageType('OfflineFeatureStoreConfig', (_message.Message,), {
  'DESCRIPTOR' : _OFFLINEFEATURESTORECONFIG,
  '__module__' : 'tecton_proto.args.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.OfflineFeatureStoreConfig)
  })
_sym_db.RegisterMessage(OfflineFeatureStoreConfig)

ParquetConfig = _reflection.GeneratedProtocolMessageType('ParquetConfig', (_message.Message,), {
  'DESCRIPTOR' : _PARQUETCONFIG,
  '__module__' : 'tecton_proto.args.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.ParquetConfig)
  })
_sym_db.RegisterMessage(ParquetConfig)

DeltaConfig = _reflection.GeneratedProtocolMessageType('DeltaConfig', (_message.Message,), {
  'DESCRIPTOR' : _DELTACONFIG,
  '__module__' : 'tecton_proto.args.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.DeltaConfig)
  })
_sym_db.RegisterMessage(DeltaConfig)

MonitoringConfig = _reflection.GeneratedProtocolMessageType('MonitoringConfig', (_message.Message,), {
  'DESCRIPTOR' : _MONITORINGCONFIG,
  '__module__' : 'tecton_proto.args.feature_view_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.args.MonitoringConfig)
  })
_sym_db.RegisterMessage(MonitoringConfig)


DESCRIPTOR._options = None
_FEATUREVIEWARGS.fields_by_name['info']._options = None
_FEATUREVIEWARGS.fields_by_name['online_enabled']._options = None
_FEATUREVIEWARGS.fields_by_name['offline_enabled']._options = None
_TEMPORALARGS.fields_by_name['feature_start_time']._options = None
_TEMPORALARGS.fields_by_name['serving_ttl']._options = None
_TEMPORALARGS.fields_by_name['monitoring']._options = None
_TEMPORALARGS.fields_by_name['backfill_config']._options = None
_TEMPORALAGGREGATEARGS.fields_by_name['aggregation_slide_period_duration']._options = None
_TEMPORALAGGREGATEARGS.fields_by_name['feature_start_time']._options = None
_TEMPORALAGGREGATEARGS.fields_by_name['monitoring']._options = None
_FEATUREAGGREGATION_FUNCTIONPARAMSENTRY._options = None
_FEATUREAGGREGATION.fields_by_name['time_window_durations']._options = None
_EXISTINGCLUSTERCONFIG.fields_by_name['existing_cluster_id']._options = None
_NEWDATABRICKSCLUSTERCONFIG.fields_by_name['instance_type']._options = None
_NEWDATABRICKSCLUSTERCONFIG.fields_by_name['instance_availability']._options = None
_NEWDATABRICKSCLUSTERCONFIG.fields_by_name['number_of_workers']._options = None
_NEWDATABRICKSCLUSTERCONFIG.fields_by_name['root_volume_size_in_gb']._options = None
_NEWDATABRICKSCLUSTERCONFIG.fields_by_name['spark_config']._options = None
_NEWDATABRICKSCLUSTERCONFIG.fields_by_name['first_on_demand']._options = None
_NEWEMRCLUSTERCONFIG.fields_by_name['instance_type']._options = None
_NEWEMRCLUSTERCONFIG.fields_by_name['instance_availability']._options = None
_NEWEMRCLUSTERCONFIG.fields_by_name['number_of_workers']._options = None
_NEWEMRCLUSTERCONFIG.fields_by_name['root_volume_size_in_gb']._options = None
_NEWEMRCLUSTERCONFIG.fields_by_name['spark_config']._options = None
_NEWEMRCLUSTERCONFIG.fields_by_name['first_on_demand']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tecton_proto/data/summary.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tecton_proto.data import fco_metadata_pb2 as tecton__proto_dot_data_dot_fco__metadata__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tecton_proto/data/summary.proto',
  package='tecton_proto.data',
  syntax='proto2',
  serialized_options=b'\n\017com.tecton.dataP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1ftecton_proto/data/summary.proto\x12\x11tecton_proto.data\x1a$tecton_proto/data/fco_metadata.proto\"\xcd\x01\n\x0bSummaryItem\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12!\n\x0c\x64isplay_name\x18\x02 \x01(\tR\x0b\x64isplayName\x12\x14\n\x05value\x18\x03 \x01(\tR\x05value\x12!\n\x0cmulti_values\x18\x04 \x03(\tR\x0bmultiValues\x12P\n\x14nested_summary_items\x18\x05 \x03(\x0b\x32\x1e.tecton_proto.data.SummaryItemR\x12nestedSummaryItems\"\x94\x01\n\nFcoSummary\x12\x41\n\x0c\x66\x63o_metadata\x18\x01 \x01(\x0b\x32\x1e.tecton_proto.data.FcoMetadataR\x0b\x66\x63oMetadata\x12\x43\n\rsummary_items\x18\x02 \x03(\x0b\x32\x1e.tecton_proto.data.SummaryItemR\x0csummaryItemsB\x13\n\x0f\x63om.tecton.dataP\x01'
  ,
  dependencies=[tecton__proto_dot_data_dot_fco__metadata__pb2.DESCRIPTOR,])




_SUMMARYITEM = _descriptor.Descriptor(
  name='SummaryItem',
  full_name='tecton_proto.data.SummaryItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='tecton_proto.data.SummaryItem.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_name', full_name='tecton_proto.data.SummaryItem.display_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='displayName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='tecton_proto.data.SummaryItem.value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='multi_values', full_name='tecton_proto.data.SummaryItem.multi_values', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='multiValues', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nested_summary_items', full_name='tecton_proto.data.SummaryItem.nested_summary_items', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nestedSummaryItems', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=93,
  serialized_end=298,
)


_FCOSUMMARY = _descriptor.Descriptor(
  name='FcoSummary',
  full_name='tecton_proto.data.FcoSummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fco_metadata', full_name='tecton_proto.data.FcoSummary.fco_metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fcoMetadata', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='summary_items', full_name='tecton_proto.data.FcoSummary.summary_items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='summaryItems', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=301,
  serialized_end=449,
)

_SUMMARYITEM.fields_by_name['nested_summary_items'].message_type = _SUMMARYITEM
_FCOSUMMARY.fields_by_name['fco_metadata'].message_type = tecton__proto_dot_data_dot_fco__metadata__pb2._FCOMETADATA
_FCOSUMMARY.fields_by_name['summary_items'].message_type = _SUMMARYITEM
DESCRIPTOR.message_types_by_name['SummaryItem'] = _SUMMARYITEM
DESCRIPTOR.message_types_by_name['FcoSummary'] = _FCOSUMMARY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SummaryItem = _reflection.GeneratedProtocolMessageType('SummaryItem', (_message.Message,), {
  'DESCRIPTOR' : _SUMMARYITEM,
  '__module__' : 'tecton_proto.data.summary_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.SummaryItem)
  })
_sym_db.RegisterMessage(SummaryItem)

FcoSummary = _reflection.GeneratedProtocolMessageType('FcoSummary', (_message.Message,), {
  'DESCRIPTOR' : _FCOSUMMARY,
  '__module__' : 'tecton_proto.data.summary_pb2'
  # @@protoc_insertion_point(class_scope:tecton_proto.data.FcoSummary)
  })
_sym_db.RegisterMessage(FcoSummary)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
